@@ -5,12 +5,11 @@
 # Copyright (c) 2013 Pablo O Vieira (povieira)
 # See README.rst and LICENSE for details.
 
-"""
-A simple script to update IP on No-IP DNS service. 
+"""A simple script to update IP on No-IP DNS service.
 """
 
 __title__ = "noipy"
-__version_info__ = ('1', '3', '0')
+__version_info__ = ('1', '3', '1')
 __version__ = ".".join(__version_info__)
 __author__ = "Pablo O Vieira"
 __email__ = "email@povieira.com"
